ytree\.tree\_farm\.tree\_farm\.TreeFarm
=======================================

.. currentmodule:: ytree.tree_farm.tree_farm

.. autoclass:: TreeFarm

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TreeFarm.__init__
      ~TreeFarm.set_ancestry_checker
      ~TreeFarm.set_ancestry_filter
      ~TreeFarm.set_ancestry_short
      ~TreeFarm.set_selector
      ~TreeFarm.trace_ancestors
      ~TreeFarm.trace_descendents
   
   

   
   
   